==> piwigo-2.1.5.zip: piwigo/language/fa_IR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Installation'] = "نصب";
$lang['Basic configuration'] = "پيکربندي ساده";
$lang['Default gallery language'] = "زبان پيش‌فرض گالري";
$lang['Database configuration'] = "پيکربندي پايگاه داده";
$lang['Admin configuration'] = "تنظيمات مديريت";
$lang['Start Install'] = "شروع نصب";
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = "آدرس ايميل بايد چيزي شبیه به xxx@yyy.eee باشد  (مانند : jack@altern.org)";
$lang['Webmaster login'] = "ورود وب‌مستر";
$lang['It will be shown to the visitors. It is necessary for website administration'] = "این برای بازدیدکنندگان نمایش‌داده و برای مدیریت وب‌سایت ضروری است";
$lang['Connection to server succeed, but it was impossible to connect to database'] = "ارتباط با سرور با موفقيت انجام شد اما ارتباط با سرور پايگاه داده با مشکل مواجه شد.";
$lang['Can\'t connect to server'] = "ارتباط با سرور ممکن نيست";
$lang['Database type'] = "نوع پايگاه داده";
$lang['The type of database your piwigo data will be store in'] = "نوع پايگاه داده گالري شما در اينجا قرار مي‌گيرد";
$lang['Host'] = "ميزبان";
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = "localhost, sql.multimania.com, toto.freesurf.fr";
$lang['User'] = "نام‌کاربري";
$lang['user login given by your host provider'] = "نام کاربري خود را بايد از سرويس‌دهنده ميزباني(هاست) دريافت نماييد";
$lang['Password'] = "گذرواژه";
$lang['user password given by your host provider'] = "گذرواژه را بايد از سرويس‌دهنده ميزباني(هاست) دريافت نماييد";
$lang['Database name'] = "نام پايگاه‌داده";
$lang['also given by your host provider'] = "اين را هم بايد از سرويس‌دهنده ميزباني(هاست) دريافت نماييد";
$lang['Database table prefix'] = "پيشوند جدول پايگاه داده";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = "تمام جدول‌های پایگاه داده با این پیشوند شروع خواهند شد.(این گزینه برای مدیریت بهتر پایگاه داده مفید است)";
$lang['enter a login for webmaster'] = "مشخصات ورود وب‌مستر را وارد نماييد";
$lang['webmaster login can\'t contain characters \' or "'] = "نبايد مشخصات ورود داراي کاراکترهاي  ' و \" باشد";
$lang['please enter your password again'] = "لطفا گذرواژه خود را مجددا وارد نماييد";
$lang['Webmaster password'] = "گذرواژه وب‌مستر";
$lang['Keep it confidential, it enables you to access administration panel'] = "این دسترسی شما را به مدیریت فراهم می‌آورد";
$lang['Password [confirm]'] = "تاييد گذرواژه";
$lang['verification'] = "تاييد";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = "به کمک نياز داريد؟ سوال خود را در <a href=\"%s\">تالارهاي پشتيباني Piwigo</a> مطرح نماييد .";
$lang['Webmaster mail address'] = "آدرس ايميل وب‌مستر";
$lang['Visitors will be able to contact site administrator with this mail'] = "بازديدکنندگان مي‌توانند با اين ايميل با مدير ارتباط برقرار کنند";
$lang['PHP 5 is required'] = "PHP 5 براي نصب گالري ضروري است";
$lang['It appears your webhost is currently running PHP %s.'] = "به نظر می‌رسد نسخه‌ی اجرا شده از PHP %s باشد.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = "Piwigo می‌تواند تنظیمات PHP شما را با ایجاد و ویرایش یک فایل .htaccess به PHP5 تغییر دهد.";
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = "شما می‌توانید خودتان پیکربندی را انجام دهید و Piwigo را مجددا راه‌اندازی کنید.";
$lang['Try to configure PHP 5'] = "پيکربندي PHP 5 را انجام دهيد";
$lang['Sorry!'] = "شرمنده!";
$lang['Piwigo was not able to configure PHP 5.'] = "Piwigo قادر به پيکربندي PHP 5 نيست.";
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = "شما باید با سرویس‌دهنده میزبانی(web hosting) خود تماس بگیرید و از آن‌ا بپرسید که چگونه می‌توانید تنظیمات خود را به PHP5 تغییر دهید.";
$lang['Hope to see you back soon.'] = "به امید دیدار";
$lang['Congratulations, Piwigo installation is completed'] = 'Piwigo با موفقیت نصب شد.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'یک راه دیگر این است که شما این متن را کپی کنید وبا نام database.inc.php در آدرس :"local/config/database.inc.php" قرار دهید.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'اشکال در ایجاد فایل local/config/database.inc.php.';
$lang['Download the config file'] = 'دريافت فايل پيکربندي';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'شما مي‌توانيد فايل پيکربندي را دانلود کنيد و آن را در دايرکتوري local/config در محلي که گالري را نصب کرديد آپلود کنيد.';
$lang['SQLite and PostgreSQL are currently in experimental state.'] = 'SQLite and PostgreSQL are currently in experimental state.';
$lang['SQLite and PostgreSQL are currently in experimental state.'] = 'SQLite و PostgreSQL در حال آزمایش هستند.(استفاده از آن‌ها یک ریسک است!)';
$lang['Learn more'] = 'اطلاعات بيشتر در اين‌باره';
?>

==> piwigo-2.3.4.zip: piwigo/language/fa_IR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Installation'] = "نصب";
$lang['Basic configuration'] = "پيکربندي ساده";
$lang['Default gallery language'] = "زبان پيش‌فرض گالري";
$lang['Database configuration'] = "پيکربندي پايگاه داده";
$lang['Admin configuration'] = "تنظيمات مديريت";
$lang['Start Install'] = "شروع نصب";
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = "آدرس ايميل بايد چيزي شبیه به xxx@yyy.eee باشد  (مانند : jack@altern.org)";
$lang['Webmaster login'] = "ورود وب‌مستر";
$lang['It will be shown to the visitors. It is necessary for website administration'] = "این برای بازدیدکنندگان نمایش‌داده و برای مدیریت وب‌سایت ضروری است";
$lang['Connection to server succeed, but it was impossible to connect to database'] = "ارتباط با سرور با موفقيت انجام شد اما ارتباط با سرور پايگاه داده با مشکل مواجه شد.";
$lang['Can\'t connect to server'] = "ارتباط با سرور ممکن نيست";
$lang['Host'] = "ميزبان";
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = "localhost, sql.multimania.com, toto.freesurf.fr";
$lang['User'] = "نام‌کاربري";
$lang['user login given by your host provider'] = "نام کاربري خود را بايد از سرويس‌دهنده ميزباني(هاست) دريافت نماييد";
$lang['Password'] = "گذرواژه";
$lang['user password given by your host provider'] = "گذرواژه را بايد از سرويس‌دهنده ميزباني(هاست) دريافت نماييد";
$lang['Database name'] = "نام پايگاه‌داده";
$lang['also given by your host provider'] = "اين را هم بايد از سرويس‌دهنده ميزباني(هاست) دريافت نماييد";
$lang['Database table prefix'] = "پيشوند جدول پايگاه داده";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = "تمام جدول‌های پایگاه داده با این پیشوند شروع خواهند شد.(این گزینه برای مدیریت بهتر پایگاه داده مفید است)";
$lang['enter a login for webmaster'] = "مشخصات ورود وب‌مستر را وارد نماييد";
$lang['webmaster login can\'t contain characters \' or "'] = "نبايد مشخصات ورود داراي کاراکترهاي  ' و \" باشد";
$lang['please enter your password again'] = "لطفا گذرواژه خود را مجددا وارد نماييد";
$lang['Webmaster password'] = "گذرواژه وب‌مستر";
$lang['Keep it confidential, it enables you to access administration panel'] = "این دسترسی شما را به مدیریت فراهم می‌آورد";
$lang['Password [confirm]'] = "تاييد گذرواژه";
$lang['verification'] = "تاييد";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = "به کمک نياز داريد؟ سوال خود را در <a href=\"%s\">تالارهاي پشتيباني Piwigo</a> مطرح نماييد .";
$lang['Webmaster mail address'] = "آدرس ايميل وب‌مستر";
$lang['Visitors will be able to contact site administrator with this mail'] = "بازديدکنندگان مي‌توانند با اين ايميل با مدير ارتباط برقرار کنند";
$lang['PHP 5 is required'] = "PHP 5 براي نصب گالري ضروري است";
$lang['It appears your webhost is currently running PHP %s.'] = "به نظر می‌رسد نسخه‌ی اجرا شده از PHP %s باشد.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = "Piwigo می‌تواند تنظیمات PHP شما را با ایجاد و ویرایش یک فایل .htaccess به PHP5 تغییر دهد.";
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = "شما می‌توانید خودتان پیکربندی را انجام دهید و Piwigo را مجددا راه‌اندازی کنید.";
$lang['Try to configure PHP 5'] = "پيکربندي PHP 5 را انجام دهيد";
$lang['Sorry!'] = "شرمنده!";
$lang['Piwigo was not able to configure PHP 5.'] = "Piwigo قادر به پيکربندي PHP 5 نيست.";
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = "شما باید با سرویس‌دهنده میزبانی(web hosting) خود تماس بگیرید و از آن‌ا بپرسید که چگونه می‌توانید تنظیمات خود را به PHP5 تغییر دهید.";
$lang['Hope to see you back soon.'] = "به امید دیدار";
$lang['Congratulations, Piwigo installation is completed'] = 'Piwigo با موفقیت نصب شد.';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'یک راه دیگر این است که شما این متن را کپی کنید وبا نام database.inc.php در آدرس :"local/config/database.inc.php" قرار دهید.';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'اشکال در ایجاد فایل local/config/database.inc.php.';
$lang['Download the config file'] = 'دريافت فايل پيکربندي';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'شما مي‌توانيد فايل پيکربندي را دانلود کنيد و آن را در دايرکتوري local/config در محلي که گالري را نصب کرديد آپلود کنيد.';
?>
